@@ -4,7 +4,20 @@
 # include <config.h>
 #endif
 
-#include "../libltdl/ltdl.h"
+#ifdef USE_LTDL
+# include "../libltdl/ltdl.h"
+#else
+# ifdef HAVE_DLFCN_H
+#  include <dlfcn.h>
+# endif
+# define lt_dlexit() 0
+# define lt_dlinit() 0
+# define lt_dlclose(x) dlclose(x)
+# define lt_dlsym(x,y) dlsym(x,y)
+# define lt_dlhandle void*
+# define lt_ptr_t void*
+# define lt_dlerror dlerror
+#endif
 
 #ifdef STDC_HEADERS
 # include <string.h>
@@ -12,6 +25,10 @@
 # include <stdio.h>
 #endif
 
+#ifdef HAVE_SYS_TYPES_H
+# include <sys/types.h>
+#endif
+
 #ifdef HAVE_DIRENT_H
 # include <dirent.h>
 #endif
