@@ -1,4 +1,6 @@
-/* Copyright (C) 1998,1999,2000 Nikos Mavroyanopoulos
+/*
+ * Copyright (C) 1998,1999,2000 Nikos Mavroyanopoulos
+ * 
  * This library is free software; you can redistribute it and/or modify it 
  * under the terms of the GNU Library General Public License as published 
  * by the Free Software Foundation; either version 2 of the License, or 
@@ -15,7 +17,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-/* $Id: mcrypt.c,v 1.25 2000/03/31 16:45:28 nikos Exp $ */
+/* $Id: mcrypt.c,v 1.2 2000/09/04 13:02:11 nmav Exp $ */
 
 /* Changed by Steve Underwood 1999/12/10 to allow an arbitrary number of 
  * streams of encryption. Currently the resulting code is probably not
@@ -46,9 +48,9 @@
 static int preloaded_symbols = 0;
 #endif
 
-int internal_end_mcrypt(MCRYPT td);
+static int internal_end_mcrypt(MCRYPT td);
 
-int internal_init_mcrypt(MCRYPT td, void *key, int lenofkey, void *IV)
+static int internal_init_mcrypt(MCRYPT td, void *key, int lenofkey, void *IV)
 {
 	int *sizes = NULL;
 	int num_of_sizes, i, ok = 0;
@@ -71,11 +73,10 @@ int internal_init_mcrypt(MCRYPT td, void *key, int lenofkey, void *IV)
 			ok = 1;
 	}
 
+	free(sizes);
 	if (ok == 0) {
-		free(sizes);
 		return MCRYPT_KEY_LEN_ERROR;
 	}
-	free(sizes);
 
 	td->keyword_given = mxcalloc(1, mcrypt_enc_get_key_size(td));
 	memmove(td->keyword_given, key, lenofkey);
