@@ -1,4 +1,6 @@
-/* Copyright (C) 1998,1999 Nikos Mavroyanopoulos
+/*
+ * Copyright (C) 1998,1999 Nikos Mavroyanopoulos
+ *
  * Encryption/decryption library. This library is free software;
  * you can redistribute it and/or modify it under the terms of the
  * GNU Library General Public License as published by the Free Software
@@ -16,7 +18,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-/* $Id: mcrypt.h,v 1.14 2000/03/21 11:20:48 nikos Exp $ */
+/* $Id: mcrypt.h,v 1.2 2000/09/16 02:01:38 nmav Exp $ */
 
 #define MCRYPT_API_VERSION 20000320
 
@@ -48,6 +50,7 @@ extern "C" {
 
 /* extra functions */
 
+     int mcrypt_enc_set_state(MCRYPT td, void *iv, int size); /* only for block algorithms */
 	int (mcrypt_enc_self_test) (MCRYPT);
 	int (mcrypt_enc_get_block_size) (MCRYPT);
 	int (mcrypt_enc_get_iv_size) (MCRYPT);
