@@ -1,4 +1,6 @@
-/* Copyright (C) 1998,1999,2000 Nikos Mavroyanopoulos
+/*
+ * Copyright (C) 1998,1999,2000 Nikos Mavroyanopoulos
+ *
  * This library is free software; you can redistribute it and/or modify it 
  * under the terms of the GNU Library General Public License as published 
  * by the Free Software Foundation; either version 2 of the License, or 
@@ -45,48 +47,106 @@ int mcrypt_module_close(MCRYPT td)
 	return 0;
 }
 
-#if 0
-int mcrypt_modules_preopen()
-{
+#ifndef USE_LTDL
+void *mcrypt_dlopen_ext ( const char *filename) {
+	void *ret;
+	char full_path[1054];
 
-	preloaded_symbols = 1;
-	LTDL_SET_PRELOADED_SYMBOLS();
+	if (strlen(filename)>sizeof(full_path)) return;
+
+	strcpy(full_path, filename);
+	ret = dlopen(full_path, RTLD_LAZY);
+
+	if (ret==NULL) {
+		strcat(full_path, ".so");
+		ret = dlopen(full_path, RTLD_LAZY);
+	}
+	return ret;
 
-	return 0;
 }
 #endif
 
+void *mcrypt_dlopen ( const char* a_directory, const char *m_directory, const char *filename) {
+	void* ret=NULL;
+
+#ifdef USE_LTDL
+	char paths[1526];
+	
+	memset( paths, 0, 1024);
+	if (a_directory != NULL) {
+		strncat( paths, a_directory, 512);
+		strcat( paths, ":");
+	}
+	if (m_directory != NULL) {
+		strncat( paths, m_directory, 512);
+		strcat( paths, ":");
+	}
+	strncat( paths, LIBDIR, 512);
+
+	lt_dlsetsearchpath(paths);
+
+	ret = lt_dlopenext(filename);
+	if (ret==NULL) ret = lt_dlopen(filename);
+
+	return ret;
+
+#else
+	char full_path[1050];
+
+	if (a_directory!=NULL) {
+		strncpy(full_path, a_directory, 512);
+		strcat(full_path, "/");
+		strncat( full_path, filename, 512);
+		ret = mcrypt_dlopen_ext(full_path);
+	}
+	if (ret==NULL) {
+		if (m_directory!=NULL) {
+			strncpy(full_path, m_directory, 512);
+			strcat(full_path, "/");
+			strncat( full_path, filename, 510);
+			ret = mcrypt_dlopen_ext(full_path);
+		}
+	}
+	if (ret==NULL) {
+		if (LIBDIR!=NULL) {
+			strncpy(full_path, LIBDIR, 512);
+			strcat(full_path, "/");
+			strncat( full_path, filename, 510);
+			ret = mcrypt_dlopen_ext(full_path);
+		}
+	}
+	return ret;
+#endif
+
+}
+
 MCRYPT mcrypt_module_open(char *algorithm,
 			  char *a_directory, char *mode, char *m_directory)
 {
 	MCRYPT td;
-
+	char* err;
+	
 	td = calloc(1, sizeof(CRYPT_STREAM));
 
 	if (lt_dlinit() != 0) {
 		return MCRYPT_FAILED;
 	}
 
-	if (a_directory != NULL)
-		lt_dladdsearchdir(a_directory);
-	if (m_directory != NULL)
-		lt_dladdsearchdir(m_directory);
-	lt_dladdsearchdir(LIBDIR);
-
 /*	LTDL_SET_PRELOADED_SYMBOLS(); */
 
-	td->algorithm_handle = lt_dlopenext(algorithm);
+	td->algorithm_handle = mcrypt_dlopen(a_directory, m_directory, algorithm);
 	if (td->algorithm_handle == NULL) {
-		fputs(lt_dlerror(), stderr);
+		err=lt_dlerror();
+		if (err!=NULL) fputs( err, stderr);
 		fputs("\n", stderr);
 		return MCRYPT_FAILED;
 	}
 
-	td->mode_handle = lt_dlopenext(mode);
+	td->mode_handle = mcrypt_dlopen(a_directory, m_directory, mode);
 
 	if (td->mode_handle == NULL) {
-		fputs(lt_dlerror(), stderr);
-		fputs("\n", stderr);
+		err=lt_dlerror();
+		if (err!=NULL) fputs( err, stderr);
 		lt_dlclose(td->algorithm_handle);
 		return MCRYPT_FAILED;
 	}
@@ -121,7 +181,7 @@ int mcrypt_get_size(MCRYPT td)
 	s = td->algorithm_handle;
 	_mcrypt_get_size = lt_dlsym(s, "_mcrypt_get_size");
 	if ((error = lt_dlerror())) {
-		fputs(error, stderr);
+		if (error!=NULL) fputs(error, stderr);
 		fputs("\n", stderr);
 		return MCRYPT_UNKNOWN_ERROR;
 	}
@@ -138,7 +198,7 @@ int mcrypt_mode_get_size(MCRYPT td)
 	s = td->mode_handle;
 	_mcrypt_get_size = lt_dlsym(s, "_mcrypt_mode_get_size");
 	if ((error = lt_dlerror())) {
-		fputs(error, stderr);
+		if (error!=NULL) fputs(error, stderr);
 		fputs("\n", stderr);
 		return MCRYPT_UNKNOWN_ERROR;
 	}
@@ -157,7 +217,7 @@ void mcrypt_set_key(MCRYPT td, void *a, void *b, int c, void *d, int e)
 		/* stream */
 		__mcrypt_set_key_stream = lt_dlsym(s, "_mcrypt_set_key");
 		if ((error = lt_dlerror())) {
-			fputs(error, stderr);
+			if (error!=NULL) fputs(error, stderr);
 			fputs("\n", stderr);
 			return;
 		}
@@ -165,7 +225,7 @@ void mcrypt_set_key(MCRYPT td, void *a, void *b, int c, void *d, int e)
 	} else {
 		__mcrypt_set_key_block = lt_dlsym(s, "_mcrypt_set_key");
 		if ((error = lt_dlerror())) {
-			fputs(error, stderr);
+			if (error!=NULL) fputs(error, stderr);
 			fputs("\n", stderr);
 			return;
 		}
@@ -173,6 +233,23 @@ void mcrypt_set_key(MCRYPT td, void *a, void *b, int c, void *d, int e)
 	}
 }
 
+int mcrypt_enc_set_state(MCRYPT td, void *iv, int size)
+{
+	int (*__mcrypt_set_state) (void *, void *, int);
+	const char *error;
+	char *s;
+
+	s = td->mode_handle;
+
+	__mcrypt_set_state = lt_dlsym(s, "_mcrypt_set_state");
+	if ((error = lt_dlerror())) {
+		if (error!=NULL) fputs(error, stderr);
+		fputs("\n", stderr);
+		return MCRYPT_UNKNOWN_ERROR;
+	}
+	return __mcrypt_set_state(td->abuf, iv, size);
+}
+
 
 int mcrypt_enc_get_block_size(MCRYPT td)
 {
@@ -401,23 +478,19 @@ int mcrypt_module_self_test(char *algorithm, char *a_directory)
 	int i;
 	lt_dlhandle *_handle;
 	int (*_self_test) (void);
-
+	char* error;
 
 
 	if (lt_dlinit() != 0) {
 		return MCRYPT_UNKNOWN_ERROR;
 	}
 /*	LTDL_SET_PRELOADED_SYMBOLS(); */
-	if (a_directory != NULL) {
-		lt_dlsetsearchpath(a_directory);
-	} else {
-		lt_dladdsearchdir(LIBDIR);
-	}
 
-	_handle = lt_dlopenext(algorithm);
+	_handle = mcrypt_dlopen(a_directory, NULL, algorithm);
 
 	if (!_handle) {
-		fputs(lt_dlerror(), stderr);
+		error=lt_dlerror();
+		if (error!=NULL) fputs( error, stderr);
 		fputs("\n", stderr);
 		return MCRYPT_UNKNOWN_ERROR;
 	}
@@ -436,20 +509,17 @@ int mcrypt_module_algorithm_version(char *algorithm, char *a_directory)
 	int i;
 	lt_dlhandle _handle;
 	int (*_version) (void);
+	char* error;
 
 	if (lt_dlinit() != 0) {
 		return MCRYPT_UNKNOWN_ERROR;
 	}
 /*	LTDL_SET_PRELOADED_SYMBOLS(); */
-	if (a_directory != NULL) {
-		lt_dlsetsearchpath(a_directory);
-	} else {
-		lt_dladdsearchdir(LIBDIR);
-	}
 
-	_handle = lt_dlopenext(algorithm);
+	_handle = mcrypt_dlopen(a_directory, NULL, algorithm);
 	if (!_handle) {
-		fputs(lt_dlerror(), stderr);
+		error=lt_dlerror();
+		if (error!=NULL) fputs( error, stderr);
 		fputs("\n", stderr);
 		return MCRYPT_UNKNOWN_ERROR;
 	}
@@ -469,20 +539,17 @@ int mcrypt_module_mode_version(char *mode, char *m_directory)
 	int i;
 	lt_dlhandle *_handle;
 	int (*_version) (void);
+	char* error;
 
 	if (lt_dlinit() != 0) {
 		return MCRYPT_UNKNOWN_ERROR;
 	}
 /*	LTDL_SET_PRELOADED_SYMBOLS(); */
-	if (m_directory != NULL) {
-		lt_dlsetsearchpath(m_directory);
-	} else {
-		lt_dladdsearchdir(LIBDIR);
-	}
 
-	_handle = lt_dlopenext(mode);
+	_handle = mcrypt_dlopen(m_directory, NULL, mode);
 	if (!_handle) {
-		fputs(lt_dlerror(), stderr);
+		error=lt_dlerror();
+		if(error!=NULL) fputs(error, stderr);
 		fputs("\n", stderr);
 		return MCRYPT_UNKNOWN_ERROR;
 	}
@@ -503,20 +570,18 @@ int mcrypt_module_is_block_algorithm(char *algorithm, char *a_directory)
 	int i;
 	lt_dlhandle _handle;
 	int (*_is_block_algorithm) (void);
-
+	char* error;
+	
 	if (lt_dlinit() != 0) {
 		return MCRYPT_UNKNOWN_ERROR;
 	}
 /*	LTDL_SET_PRELOADED_SYMBOLS(); */
-	if (a_directory != NULL) {
-		lt_dlsetsearchpath(a_directory);
-	} else {
-		lt_dladdsearchdir(LIBDIR);
-	}
 
-	_handle = lt_dlopenext(algorithm);
+	_handle = mcrypt_dlopen(a_directory, NULL, algorithm);
+	
 	if (!_handle) {
-		fputs(lt_dlerror(), stderr);
+		error=lt_dlerror();
+		if(error!=NULL) fputs( error, stderr);
 		fputs("\n", stderr);
 		return MCRYPT_UNKNOWN_ERROR;
 	}
@@ -537,20 +602,17 @@ int mcrypt_module_is_block_algorithm_mode(char *mode, char *m_directory)
 	int i;
 	lt_dlhandle *_handle;
 	int (*_is_a_block_mode) (void);
+	char* error;
 
 	if (lt_dlinit() != 0) {
 		return MCRYPT_UNKNOWN_ERROR;
 	}
 /*	LTDL_SET_PRELOADED_SYMBOLS(); */
-	if (m_directory != NULL) {
-		lt_dlsetsearchpath(m_directory);
-	} else {
-		lt_dladdsearchdir(LIBDIR);
-	}
 
-	_handle = lt_dlopenext(mode);
+	_handle = mcrypt_dlopen(m_directory, NULL, mode);
 	if (!_handle) {
-		fputs(lt_dlerror(), stderr);
+		error=lt_dlerror();
+		if(error!=NULL) fputs( error, stderr);
 		fputs("\n", stderr);
 		return MCRYPT_UNKNOWN_ERROR;
 	}
@@ -571,21 +633,17 @@ int mcrypt_module_is_block_mode(char *mode, char *m_directory)
 	int i;
 	lt_dlhandle *_handle;
 	int (*_is_block_mode) (void);
-
+	char* error;
 
 	if (lt_dlinit() != 0) {
 		return MCRYPT_UNKNOWN_ERROR;
 	}
 /*	LTDL_SET_PRELOADED_SYMBOLS(); */
-	if (m_directory != NULL) {
-		lt_dlsetsearchpath(m_directory);
-	} else {
-		lt_dladdsearchdir(LIBDIR);
-	}
 
-	_handle = lt_dlopenext(mode);
+	_handle = mcrypt_dlopen(m_directory, NULL, mode);
 	if (!_handle) {
-		fputs(lt_dlerror(), stderr);
+		error=lt_dlerror();
+		if(error!=NULL) fputs( error, stderr);
 		fputs("\n", stderr);
 		return MCRYPT_UNKNOWN_ERROR;
 	}
@@ -605,20 +663,17 @@ int mcrypt_module_get_algo_block_size(char *algorithm, char *a_directory)
 	int i;
 	lt_dlhandle _handle;
 	int (*_get_block_size) (void);
+	char* error;
 
 	if (lt_dlinit() != 0) {
 		return MCRYPT_UNKNOWN_ERROR;
 	}
 /*	LTDL_SET_PRELOADED_SYMBOLS(); */
-	if (a_directory != NULL) {
-		lt_dlsetsearchpath(a_directory);
-	} else {
-		lt_dladdsearchdir(LIBDIR);
-	}
 
-	_handle = lt_dlopenext(algorithm);
+	_handle = mcrypt_dlopen(a_directory, NULL, algorithm);
 	if (!_handle) {
-		fputs(lt_dlerror(), stderr);
+		error=lt_dlerror();
+		if(error!=NULL) fputs( error, stderr);
 		fputs("\n", stderr);
 		return MCRYPT_UNKNOWN_ERROR;
 	}
@@ -638,20 +693,17 @@ int mcrypt_module_get_algo_key_size(char *algorithm, char *a_directory)
 	int i;
 	lt_dlhandle _handle;
 	int (*_get_key_size) (void);
+	char* error;
 
 	if (lt_dlinit() != 0) {
 		return MCRYPT_UNKNOWN_ERROR;
 	}
 /*	LTDL_SET_PRELOADED_SYMBOLS(); */
-	if (a_directory != NULL) {
-		lt_dlsetsearchpath(a_directory);
-	} else {
-		lt_dladdsearchdir(LIBDIR);
-	}
 
-	_handle = lt_dlopenext(algorithm);
+	_handle = mcrypt_dlopen(a_directory, NULL, algorithm);
 	if (!_handle) {
-		fputs(lt_dlerror(), stderr);
+		error=lt_dlerror();
+		if(error!=NULL) fputs( error, stderr);
 		fputs("\n", stderr);
 		return MCRYPT_UNKNOWN_ERROR;
 	}
@@ -674,21 +726,18 @@ int *mcrypt_module_get_algo_supported_key_sizes(char *algorithm,
 	lt_dlhandle _handle;
 	int *(*_mcrypt_get_key_sizes) (int *);
 	int *size;
+	char* error;
 
 	if (lt_dlinit() != 0) {
 		*len = 0;
 		return NULL;
 	}
 /*	LTDL_SET_PRELOADED_SYMBOLS(); */
-	if (a_directory != NULL) {
-		lt_dlsetsearchpath(a_directory);
-	} else {
-		lt_dladdsearchdir(LIBDIR);
-	}
 
-	_handle = lt_dlopenext(algorithm);
+	_handle = mcrypt_dlopen(a_directory, NULL, algorithm);
 	if (!_handle) {
-		fputs(lt_dlerror(), stderr);
+		error=lt_dlerror();
+		if(error!=NULL) fputs( error, stderr);
 		fputs("\n", stderr);
 		*len = 0;
 		return NULL;
