@@ -5,7 +5,11 @@
 * found in ftp://ftp.funet.fi/pub/crypt/                             *
 \********************************************************************/
 
-/* $Id: 3-way.c,v 1.7 2000/02/02 20:15:50 nikos Exp $ */
+/* modified in order to use the libmcrypt API by Nikos Mavroyanopoulos 
+ * All modifications are placed under the license of libmcrypt.
+ */
+
+/* $Id: 3-way.c,v 1.2 2000/09/16 02:01:38 nmav Exp $ */
 
 #include "../../lib/libdefs.h"
 #include "../../lib/mcrypt_modules.h"
@@ -15,6 +19,7 @@
 #define   STRT_D   0xb1b1	/* round constant of first decryption round */
 #define     NMBR       11	/* number of rounds is 11                   */
 
+#ifdef USE_LTDL
 #define _mcrypt_set_key threeway_LTX__mcrypt_set_key
 #define _mcrypt_encrypt threeway_LTX__mcrypt_encrypt
 #define _mcrypt_decrypt threeway_LTX__mcrypt_decrypt
@@ -26,6 +31,7 @@
 #define _mcrypt_get_algorithms_name threeway_LTX__mcrypt_get_algorithms_name
 #define _mcrypt_self_test threeway_LTX__mcrypt_self_test
 #define _mcrypt_algorithm_version threeway_LTX__mcrypt_algorithm_version
+#endif
 
 void _mcrypt_set_key (word32 *k, word32* input_key, int len) {
         k[0]=0;         k[2]=0;
