@@ -1,4 +1,6 @@
-/* Copyright (C) 1998,1999 Nikos Mavroyanopoulos
+/* 
+ * Copyright (C) 1998,1999 Nikos Mavroyanopoulos
+ *
  * This library is free software; you can redistribute it and/or modify it 
  * under the terms of the GNU Library General Public License as published 
  * by the Free Software Foundation; either version 2 of the License, or 
@@ -20,6 +22,7 @@
 #include <stdlib.h>
 #include "arcfour.h"
 
+#ifdef USE_LTDL
 #define _mcrypt_set_key arcfour_LTX__mcrypt_set_key
 #define _mcrypt_encrypt arcfour_LTX__mcrypt_encrypt
 #define _mcrypt_decrypt arcfour_LTX__mcrypt_decrypt
@@ -32,6 +35,7 @@
 #define _mcrypt_get_algorithms_name arcfour_LTX__mcrypt_get_algorithms_name
 #define _mcrypt_self_test arcfour_LTX__mcrypt_self_test
 #define _mcrypt_algorithm_version arcfour_LTX__mcrypt_algorithm_version
+#endif
 
 #define swap_byte(x,y) t = *(x); *(x) = *(y); *(y) = t
 
