@@ -3,12 +3,17 @@
  * Changed to conform to the "new" blowfish posted in 30 Oct 1994
  */
 
-/* $Id: blowfish.c,v 1.5 2000/02/02 20:15:50 nikos Exp $ */
+/* modified in order to use the libmcrypt API by Nikos Mavroyanopoulos 
+ * All modifications are placed under the license of libmcrypt.
+ */
+
+/* $Id: blowfish.c,v 1.3 2000/09/16 02:01:38 nmav Exp $ */
 
 #include "../../lib/libdefs.h"
 #include "../../lib/mcrypt_modules.h"
 #include "blowfish.h"
 
+#ifdef USE_LTDL
 #define _mcrypt_set_key blowfish_LTX__mcrypt_set_key
 #define _mcrypt_encrypt blowfish_LTX__mcrypt_encrypt
 #define _mcrypt_decrypt blowfish_LTX__mcrypt_decrypt
@@ -20,6 +25,7 @@
 #define _mcrypt_get_algorithms_name blowfish_LTX__mcrypt_get_algorithms_name
 #define _mcrypt_self_test blowfish_LTX__mcrypt_self_test
 #define _mcrypt_algorithm_version blowfish_LTX__mcrypt_algorithm_version
+#endif
 
 /*
 typedef struct {
@@ -29,56 +35,13 @@ typedef struct {
 
 #define MAXKEYBYTES 56		/* 448 bits */
 
-#define N         16
+#define BF_N         16
 #define KEYBYTES   8
 
-#ifdef WORDS_BIGENDIAN
-/* ABCD - big endian - motorola */
-union aword {
-	word32 word;
-	word8 byte[4];
-	struct {
-		unsigned int byte0:8;
-		unsigned int byte1:8;
-		unsigned int byte2:8;
-		unsigned int byte3:8;
-	} w;
-};
-#else
-
-/* DCBA - little endian - intel */
-union aword {
-	word32 word;
-	word8 byte[4];
-	struct {
-		unsigned int byte3:8;
-		unsigned int byte2:8;
-		unsigned int byte1:8;
-		unsigned int byte0:8;
-	} w;
-};
-#endif
-
-
-word32 F(blf_ctx * bc, word32 x)
+static word32 F(blf_ctx * bc, word32 x)
 {
-	word16 a;
-	word16 b;
-	word16 c;
-	word16 d;
-	word32 y;
+	return ((bc->S[0][(x >> 24) & 0xff] + bc->S[1][(x >> 16) & 0xff]) ^ bc->S[2][(x >>  8) & 0xff]) + bc->S[3][(x      ) & 0xff];
 
-	union aword temp;
-
-	temp.word = x;
-	d = temp.w.byte3;
-	c = temp.w.byte2;
-	b = temp.w.byte1;
-	a = temp.w.byte0;
-
-	y = ((bc->S[0][a] + bc->S[1][b]) ^ bc->S[2][c]) + bc->S[3][d];
-
-	return y;
 }
 
 /* x should be a 64 bit integer */
@@ -96,7 +59,7 @@ void _mcrypt_encrypt(blf_ctx * c, word32 * x)
 	Xr = byteswap(x[1]);
 #endif
 
-	for (i = 0; i < N; ++i) {
+for (i = 0; i < BF_N; ++i) {
 		Xl ^= c->P[i];
 		Xr ^= F(c, Xl);
 
@@ -109,8 +72,8 @@ void _mcrypt_encrypt(blf_ctx * c, word32 * x)
 	Xl = Xr;
 	Xr = temp;
 
-	Xr ^= c->P[N];
-	Xl ^= c->P[N + 1];
+	Xr ^= c->P[BF_N];
+	Xl ^= c->P[BF_N + 1];
 
 #ifndef WORDS_BIGENDIAN
 	x[0] = Xl;
@@ -123,7 +86,7 @@ void _mcrypt_encrypt(blf_ctx * c, word32 * x)
 }
 
 /* x should be a 64 bit integer */
-void enblf_noswap(blf_ctx * c, word32 * x)
+static void enblf_noswap(blf_ctx * c, word32 * x)
 {				/* Used internally */
 	word32 Xl;
 	word32 Xr, temp;
@@ -132,7 +95,7 @@ void enblf_noswap(blf_ctx * c, word32 * x)
 	Xl = x[0];
 	Xr = x[1];
 
-	for (i = 0; i < N; ++i) {
+	for (i = 0; i < BF_N; ++i) {
 		Xl ^= c->P[i];
 		Xr ^= F(c, Xl);
 
@@ -145,8 +108,8 @@ void enblf_noswap(blf_ctx * c, word32 * x)
 	Xl = Xr;
 	Xr = temp;
 
-	Xr ^= c->P[N];
-	Xl ^= c->P[N + 1];
+	Xr ^= c->P[BF_N];
+	Xl ^= c->P[BF_N + 1];
 
 	x[0] = Xl;
 	x[1] = Xr;
@@ -165,7 +128,7 @@ void _mcrypt_decrypt(blf_ctx * c, word32 * x)
 	Xr = byteswap(x[1]);
 #endif
 
-	for (i = N + 1; i > 1; --i) {
+	for (i = BF_N + 1; i > 1; --i) {
 		Xl ^= c->P[i];
 		Xr ^= F(c, Xl);
 
@@ -191,11 +154,10 @@ void _mcrypt_decrypt(blf_ctx * c, word32 * x)
 }
 
 
-short initialize_blowfish(blf_ctx * c, char key[], short keybytes)
+static short initialize_blowfish(blf_ctx * c, char key[], short keybytes)
 {
 	short i, j;
 	word32 data, datarl[2];
-	union aword temp;
 
 	word32 ks0[] = {
 		0xd1310ba6L, 0x98dfb5acL, 0x2ffd72dbL, 0xd01adfb7L,
@@ -574,22 +536,21 @@ short initialize_blowfish(blf_ctx * c, char key[], short keybytes)
 	}
 
 	j = 0;
-	for (i = 0; i < N + 2; ++i) {
-		temp.word = 0;
-		temp.w.byte0 = key[j];
-		temp.w.byte1 = key[(j + 1) % keybytes];
-		temp.w.byte2 = key[(j + 2) % keybytes];
-		temp.w.byte3 = key[(j + 3) % keybytes];
-		data = temp.word;
-
-		c->P[i] = c->P[i] ^ data;
-		j = (j + 4) % keybytes;
+	for (i = 0; i < BF_N + 2; ++i) {
+                data = 0x00000000;
+                data = (data << 8) | key[(j)   % keybytes];
+                data = (data << 8) | key[(j+1) % keybytes];
+                data = (data << 8) | key[(j+2) % keybytes];
+                data = (data << 8) | key[(j+3) % keybytes];
+ 
+                c->P[i] ^= data;
+                j = (j + 4) % keybytes;
 	}
 
 	datarl[0] = 0x000000000;
 	datarl[1] = 0x000000000;
 
-	for (i = 0; i < N + 2; i += 2) {
+	for (i = 0; i < BF_N + 2; i += 2) {
 		enblf_noswap(c, datarl);
 		c->P[i] = datarl[0];
 		c->P[i + 1] = datarl[1];
