@@ -1,6 +1,5 @@
-
 /*
- * $Id: cast-128.c,v 1.6 2000/02/02 20:15:50 nikos Exp $
+ * $Id: cast-128.c,v 1.2 2000/09/16 02:01:38 nmav Exp $
  *
  *	CAST-128 in C
  *	Written by Steve Reid <sreid@sea-to-sky.net>
@@ -10,12 +9,17 @@
 
 /* Adapted to the pike cryptographic toolkit by Niels Mller */
 
-/* $Id: cast-128.c,v 1.6 2000/02/02 20:15:50 nikos Exp $ */
+/* modified in order to use the libmcrypt API by Nikos Mavroyanopoulos 
+ * All modifications are placed under the license of libmcrypt.
+ */
+
+/* $Id: cast-128.c,v 1.2 2000/09/16 02:01:38 nmav Exp $ */
 
 #include "../../lib/libdefs.h"
 #include "../../lib/mcrypt_modules.h"
 #include "cast-128.h"
 
+#ifdef USE_LTDL
 #define _mcrypt_set_key cast_128_LTX__mcrypt_set_key
 #define _mcrypt_encrypt cast_128_LTX__mcrypt_encrypt
 #define _mcrypt_decrypt cast_128_LTX__mcrypt_decrypt
@@ -27,6 +31,7 @@
 #define _mcrypt_get_algorithms_name cast_128_LTX__mcrypt_get_algorithms_name
 #define _mcrypt_self_test cast_128_LTX__mcrypt_self_test
 #define _mcrypt_algorithm_version cast_128_LTX__mcrypt_algorithm_version
+#endif
 
 #define u8 word8
 #define u32 word32
