@@ -12,7 +12,11 @@
 /*                                                                      */
 /* Dr Brian Gladman (gladman@seven77.demon.co.uk) 14th January 1999     */
 
-/* $Id: cast-256.c,v 1.6 2000/02/02 20:15:50 nikos Exp $ */
+/* modified in order to use the libmcrypt API by Nikos Mavroyanopoulos 
+ * All modifications are placed under the license of libmcrypt.
+ */
+
+/* $Id: cast-256.c,v 1.2 2000/09/16 02:01:38 nmav Exp $ */
 
 /* modified for mcrypt */
 
@@ -64,6 +68,7 @@ Mean:          674 cycles =    38.0 mbits/sec
 #include "../../lib/mcrypt_modules.h"
 #include "cast-256.h"
 
+#ifdef USE_LTDL
 #define _mcrypt_set_key cast_256_LTX__mcrypt_set_key
 #define _mcrypt_encrypt cast_256_LTX__mcrypt_encrypt
 #define _mcrypt_decrypt cast_256_LTX__mcrypt_decrypt
@@ -75,6 +80,7 @@ Mean:          674 cycles =    38.0 mbits/sec
 #define _mcrypt_get_algorithms_name cast_256_LTX__mcrypt_get_algorithms_name
 #define _mcrypt_self_test cast_256_LTX__mcrypt_self_test
 #define _mcrypt_algorithm_version cast_256_LTX__mcrypt_algorithm_version
+#endif
 
 #define byte(x,n)   ((word8)((x) >> (8 * n)))
 
