@@ -10,12 +10,17 @@
  *	char kn[16][8];
  */
 
-/* $Id: des.c,v 1.7 2000/02/09 15:15:06 nikos Exp $ */
+/* modified in order to use the libmcrypt API by Nikos Mavroyanopoulos 
+ * All modifications are placed under the license of libmcrypt.
+ */
+
+/* $Id: des.c,v 1.2 2000/09/16 02:01:38 nmav Exp $ */
 
 #include "../../lib/libdefs.h"
 #include "../../lib/mcrypt_modules.h"
 #include "des.h"
 
+#ifdef USE_LTDL
 #define _mcrypt_set_key des_LTX__mcrypt_set_key
 #define _mcrypt_encrypt des_LTX__mcrypt_encrypt
 #define _mcrypt_decrypt des_LTX__mcrypt_decrypt
@@ -27,6 +32,7 @@
 #define _mcrypt_get_algorithms_name des_LTX__mcrypt_get_algorithms_name
 #define _mcrypt_self_test des_LTX__mcrypt_self_test
 #define _mcrypt_algorithm_version des_LTX__mcrypt_algorithm_version
+#endif
 
 /* #define	NULL	0 */
 
