@@ -12,9 +12,11 @@
 /*                                                                      */
 /* Dr Brian Gladman (gladman@seven77.demon.co.uk) 14th January 1999     */
 
-/* $Id: loki97.c,v 1.6 2000/02/02 20:15:50 nikos Exp $ */
+/* $Id: loki97.c,v 1.2 2000/09/16 02:01:38 nmav Exp $ */
 
-/* modified for mcrypt */
+/* modified in order to use the libmcrypt API by Nikos Mavroyanopoulos 
+ * All modifications are placed under the license of libmcrypt.
+ */
 
 /* Timing data for LOKI97 (loki.c)
 
@@ -64,6 +66,7 @@ Mean:         2186 cycles =    11.7 mbits/sec
 #include "../../lib/libdefs.h"
 #include "../../lib/mcrypt_modules.h"
 
+#ifdef USE_LTDL
 #define _mcrypt_set_key loki97_LTX__mcrypt_set_key
 #define _mcrypt_encrypt loki97_LTX__mcrypt_encrypt
 #define _mcrypt_decrypt loki97_LTX__mcrypt_decrypt
@@ -75,6 +78,7 @@ Mean:         2186 cycles =    11.7 mbits/sec
 #define _mcrypt_get_algorithms_name loki97_LTX__mcrypt_get_algorithms_name
 #define _mcrypt_self_test loki97_LTX__mcrypt_self_test
 #define _mcrypt_algorithm_version loki97_LTX__mcrypt_algorithm_version
+#endif
 
 #define byte(x,n)   ((word8)((x) >> (8 * n)))
 
