@@ -1,6 +1,6 @@
 /* panama_x.c */
 
-/* $Id: panama.c,v 1.3 2000/03/19 14:08:34 nikos Exp $ */
+/* $Id: panama.c,v 1.3 2000/09/16 02:01:38 nmav Exp $ */
 
 /* daemen.j@protonworld.com */
 /**************************************************************************+
@@ -32,11 +32,16 @@
 *
 +**************************************************************************/
 
+/* modified in order to use the libmcrypt API by Nikos Mavroyanopoulos 
+ * All modifications are placed under the license of libmcrypt.
+ */
+
 #include "../../lib/libdefs.h"
 #include "../../lib/mcrypt_modules.h"
 #include "panama.h"
 
 
+#ifdef USE_LTDL
 #define _mcrypt_set_key panama_LTX__mcrypt_set_key
 #define _mcrypt_encrypt panama_LTX__mcrypt_encrypt
 #define _mcrypt_decrypt panama_LTX__mcrypt_decrypt
@@ -49,6 +54,7 @@
 #define _mcrypt_get_algorithms_name panama_LTX__mcrypt_get_algorithms_name
 #define _mcrypt_self_test panama_LTX__mcrypt_self_test
 #define _mcrypt_algorithm_version panama_LTX__mcrypt_algorithm_version
+#endif
 
 /**************************************************************************+
 *                         Panama internal routines                         *
@@ -656,9 +662,10 @@ int _mcrypt_self_test() {
 	        printf("Expected: %s\nGot: %s\n", CIPHER, (char*)cipher_tmp);
 	        return -1;
 	}
-//        for (j=0; j< _mcrypt_get_key_size(); j++) {
-//	        keyword[j]=((j*2+10)%256);
-//	}
+/*        for (j=0; j< _mcrypt_get_key_size(); j++) {
+	        keyword[j]=((j*2+10)%256);
+	}
+ */
 	_mcrypt_set_key( key, (void*)keyword, _mcrypt_get_key_size(), NULL,0);
 	_mcrypt_decrypt( key, (void*)ciphertext,  blocksize);
 
