@@ -17,7 +17,12 @@
 *
 *******************************************************************************/
 
-/* $Id: safer128.c,v 1.6 2000/02/02 20:15:50 nikos Exp $ */
+/* modified in order to use the libmcrypt API by Nikos Mavroyanopoulos 
+ * All modifications are placed under the license of libmcrypt.
+ */
+
+
+/* $Id: safer128.c,v 1.2 2000/09/16 02:01:38 nmav Exp $ */
 
 /******************* External Headers *****************************************/
 
@@ -26,6 +31,7 @@
 #include "../../lib/mcrypt_modules.h"
 #include "safer.h"
 
+#ifdef USE_LTDL
 #define _mcrypt_set_key safer_sk128_LTX__mcrypt_set_key
 #define _mcrypt_encrypt safer_sk128_LTX__mcrypt_encrypt
 #define _mcrypt_decrypt safer_sk128_LTX__mcrypt_decrypt
@@ -37,6 +43,7 @@
 #define _mcrypt_get_algorithms_name safer_sk128_LTX__mcrypt_get_algorithms_name
 #define _mcrypt_self_test safer_sk128_LTX__mcrypt_self_test
 #define _mcrypt_algorithm_version safer_sk128_LTX__mcrypt_algorithm_version
+#endif
 
 /******************* Constants ************************************************/
 #define TAB_LEN      256
