@@ -12,9 +12,12 @@
 /*                                                                      */
 /* Dr Brian Gladman (gladman@seven77.demon.co.uk) 14th January 1999     */
 
-/* $Id: saferplus.c,v 1.5 2000/02/02 20:15:50 nikos Exp $ */
+/* $Id: saferplus.c,v 1.2 2000/09/16 02:01:38 nmav Exp $ */
+
+/* modified in order to use the libmcrypt API by Nikos Mavroyanopoulos 
+ * All modifications are placed under the license of libmcrypt.
+ */
 
-/* modified for mcrypt */
 
 /* Timing data for SAFER+ (safer.c)
 
@@ -65,6 +68,7 @@ Mean:         3392 cycles =     7.5 mbits/sec
 #include "saferplus.h"
 #include <stdlib.h>
 
+#ifdef USE_LTDL
 #define _mcrypt_set_key saferplus_LTX__mcrypt_set_key
 #define _mcrypt_encrypt saferplus_LTX__mcrypt_encrypt
 #define _mcrypt_decrypt saferplus_LTX__mcrypt_decrypt
@@ -76,6 +80,7 @@ Mean:         3392 cycles =     7.5 mbits/sec
 #define _mcrypt_get_algorithms_name saferplus_LTX__mcrypt_get_algorithms_name
 #define _mcrypt_self_test saferplus_LTX__mcrypt_self_test
 #define _mcrypt_algorithm_version saferplus_LTX__mcrypt_algorithm_version
+#endif
 
 word8 safer_expf[256] =
     { 1, 45, 226, 147, 190, 69, 21, 174, 120, 3, 135, 164, 184, 56, 207,
