@@ -13,6 +13,10 @@
  * Dr Brian Gladman (gladman@seven77.demon.co.uk) 14th January 1999
  */
 
+/* modified in order to use the libmcrypt API by Nikos Mavroyanopoulos 
+ * All modifications are placed under the license of libmcrypt.
+ */
+
 /*
 Algorithm serpent (serpent.c)
 
@@ -39,6 +43,7 @@ Mean:          941 cycles =    27.2 mbits/sec
 #include "../../lib/mcrypt_modules.h"
 #include "serpent.h"
 
+#ifdef USE_LTDL
 #define _mcrypt_set_key serpent_LTX__mcrypt_set_key
 #define _mcrypt_encrypt serpent_LTX__mcrypt_encrypt
 #define _mcrypt_decrypt serpent_LTX__mcrypt_decrypt
@@ -50,6 +55,7 @@ Mean:          941 cycles =    27.2 mbits/sec
 #define _mcrypt_get_algorithms_name serpent_LTX__mcrypt_get_algorithms_name
 #define _mcrypt_self_test serpent_LTX__mcrypt_self_test
 #define _mcrypt_algorithm_version serpent_LTX__mcrypt_algorithm_version
+#endif
 
 /* Partially optimised Serpent S Box boolean functions derived  */
 /* using a recursive descent analyser but without a full search */
