@@ -4,23 +4,25 @@
  * the 1977 public-domain program by Jim Gillogly
  * Modified for additional speed - 6 December 1988 Phil Karn
  * Modified for parameterized key schedules - Jan 1991 Phil Karn
+ * Modified modified such that will operate in EDE 3DES - 1999 Nikos Mavroyanopoulos
+ *
  * Callers now allocate a key schedule as follows:
  *	kn = (char (*)[8])malloc(sizeof(char) * 8 * 16);
  *	or
  *	char kn[16][8];
  */
 
-/* This is the single des implementation modified such that will operate
- * in EDE 3DES. Modified for libmcrypt
- * --nikos
+/* modified in order to use the libmcrypt API by Nikos Mavroyanopoulos 
+ * All modifications are placed under the license of libmcrypt.
  */
  
-/* $Id: tripledes.c,v 1.9 2000/02/09 15:15:06 nikos Exp $ */
+/* $Id: tripledes.c,v 1.2 2000/09/16 02:01:38 nmav Exp $ */
 
 #include "../../lib/libdefs.h"
 #include "../../lib/mcrypt_modules.h"
 #include "tripledes.h"
 
+#ifdef USE_LTDL
 #define _mcrypt_set_key tripledes_LTX__mcrypt_set_key
 #define _mcrypt_encrypt tripledes_LTX__mcrypt_encrypt
 #define _mcrypt_decrypt tripledes_LTX__mcrypt_decrypt
@@ -32,6 +34,7 @@
 #define _mcrypt_get_algorithms_name tripledes_LTX__mcrypt_get_algorithms_name
 #define _mcrypt_self_test tripledes_LTX__mcrypt_self_test
 #define _mcrypt_algorithm_version tripledes_LTX__mcrypt_algorithm_version
+#endif
 
 /* #define	NULL	0 */
 
