@@ -16,7 +16,11 @@
 /*                                                                      */
 /* Dr Brian Gladman (gladman@seven77.demon.co.uk) 14th January 1999     */
 
-/* $Id: twofish.c,v 1.5 2000/02/02 20:15:50 nikos Exp $ */
+/* modified in order to use the libmcrypt API by Nikos Mavroyanopoulos 
+ * All modifications are placed under the license of libmcrypt.
+ */
+
+/* $Id: twofish.c,v 1.2 2000/09/16 02:01:38 nmav Exp $ */
 
 /* Timing data for Twofish (twofish.c)
 
@@ -44,6 +48,7 @@
 #include "../../lib/mcrypt_modules.h"
 #include "twofish.h"
 
+#ifdef USE_LTDL
 #define _mcrypt_set_key twofish_LTX__mcrypt_set_key
 #define _mcrypt_encrypt twofish_LTX__mcrypt_encrypt
 #define _mcrypt_decrypt twofish_LTX__mcrypt_decrypt
@@ -55,6 +60,7 @@
 #define _mcrypt_get_algorithms_name twofish_LTX__mcrypt_get_algorithms_name
 #define _mcrypt_self_test twofish_LTX__mcrypt_self_test
 #define _mcrypt_algorithm_version twofish_LTX__mcrypt_algorithm_version
+#endif
 
 /* word32  k_len;
  * word32  l_key[40];
