@@ -4,11 +4,16 @@
    (extended version)
  **********************************************************/
 
-/* $Id: xtea.c,v 1.5 2000/02/02 20:15:50 nikos Exp $ */
+/* $Id: xtea.c,v 1.2 2000/09/16 02:01:38 nmav Exp $ */
+
+/* modified in order to use the libmcrypt API by Nikos Mavroyanopoulos 
+ * All modifications are placed under the license of libmcrypt.
+ */
 
 #include "../../lib/libdefs.h"
 #include "../../lib/mcrypt_modules.h"
 
+#ifdef USE_LTDL
 #define _mcrypt_set_key xtea_LTX__mcrypt_set_key
 #define _mcrypt_encrypt xtea_LTX__mcrypt_encrypt
 #define _mcrypt_decrypt xtea_LTX__mcrypt_decrypt
@@ -20,6 +25,7 @@
 #define _mcrypt_get_algorithms_name xtea_LTX__mcrypt_get_algorithms_name
 #define _mcrypt_self_test xtea_LTX__mcrypt_self_test
 #define _mcrypt_algorithm_version xtea_LTX__mcrypt_algorithm_version
+#endif
 
 #define ROUNDS 32
 #define DELTA 0x9e3779b9	/* sqr(5)-1 * 2^31 */
